import * as AWS from 'aws-sdk';
import { ILogger } from 'typescript-ilogger';
import { BaseClass } from 'typescript-helper-functions';
import { IKMSHelper } from './interface';
/**
 * KMS Helper
 */
export declare class KMSHelper extends BaseClass implements IKMSHelper {
    /**
     * AWS Repository for KMS
     */
    Repository: AWS.KMS;
    /**
     * Initializes new instance of KMSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.KMS} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.KMS.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger: ILogger, repository?: AWS.KMS, options?: AWS.KMS.ClientConfiguration);
    /**
     * Decrypt KMS
     * @param encryptedValue {string} Value to decrypt
     */
    DecryptAsync(encryptedValue: string): Promise<AWS.KMS.DecryptResponse>;
    /**
     * Encrypt KMS
     * @param unencryptedValue {string} Value to encrypt
     */
    EncryptAsync(unencryptedValue: string): Promise<AWS.KMS.EncryptResponse>;
}
