"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const mock_1 = require("./mock");
const test_values_1 = require("./test-values");
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const mockerResolves = new mock_1.KMSMock(false);
const kmsHelperMockResolves = new helper_1.KMSHelper(logger, mockerResolves.Mock);
const mockerRejects = new mock_1.KMSMock(true);
const kmsHelperMockRejects = new helper_1.KMSHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestingValues();
/**
 * Test the DecryptAsync method
 */
describe(`${helper_1.KMSHelper.name}.${kmsHelperMockResolves.DecryptAsync.name}`, () => {
    // set action for this method
    const action = `${helper_1.KMSHelper.name}.${kmsHelperMockResolves.DecryptAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} encryptedValue`, () => {
        const actual = kmsHelperMockResolves.DecryptAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} encryptedValue`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = kmsHelperMockRejects.DecryptAsync(TestValues.StringValue);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = kmsHelperMockResolves.DecryptAsync(TestValues.StringValue);
        return expect(actual).resolves.toEqual(mockerResolves.DecryptResponse);
    });
});
/**
 * Test the EncryptAsync method
 */
describe(`${helper_1.KMSHelper.name}.${kmsHelperMockResolves.EncryptAsync.name}`, () => {
    // set action for this method
    const action = `${helper_1.KMSHelper.name}.${kmsHelperMockResolves.EncryptAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} unencryptedValue`, () => {
        const actual = kmsHelperMockResolves.EncryptAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} unencryptedValue`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = kmsHelperMockRejects.EncryptAsync(TestValues.StringValue);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = kmsHelperMockResolves.EncryptAsync(TestValues.StringValue);
        return expect(actual).resolves.toEqual(mockerResolves.EncryptResponse);
    });
});
//# sourceMappingURL=helper.spec.js.map